%define anolis_release 2	
Summary:	Automated text file generator
Name:		autogen
Version:	5.18.16
Release:	%{anolis_release}%{?dist}
# Some files are licensed under GPLv2+.
# We redistribute them under GPLv3+.
License:	GPLv3+
URL:		http://www.gnu.org/software/autogen/
Source0:	ftp://ftp.gnu.org/gnu/autogen/rel%{version}/%{name}-%{version}.tar.xz

# https://sourceforge.net/p/autogen/bugs/196/
Patch1:         0001-guile-version.patch
# refer to commit 132576313e66ee270ebb70f82afdaeacec1f2fc1
Patch2:         0002-remove-guile-version-check.patch
# fix build error with -Werror=dangling-pointer=
Patch1000:      1000-fix-dangle-pointer.patch

Requires:	%{name}-libopts = %{version}-%{release}

BuildRequires:	gcc
BuildRequires:	guile-devel
BuildRequires:	libtool
BuildRequires:	libxml2-devel
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(lib)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Text::ParseWords)
BuildRequires:	perl(warnings)
BuildRequires:	chrpath
BuildRequires:	sed

%description
AutoGen is a tool designed to simplify the creation and maintenance of
programs that contain large amounts of repetitious text. It is especially
valuable in programs that have several blocks of text that must be kept
synchronised.

%package libopts
Summary:	Automated option processing library based on %{name}
# Although sources are dual licensed with BSD, some autogen generated files
# are only under LGPLv3+. We drop BSD to avoid multiple licensing scenario.
License:	LGPLv3+

%description libopts
Libopts is very powerful command line option parser consisting of a set of
AutoGen templates and a run time library that nearly eliminates the hassle of
parsing and documenting command line options.

%package libopts-devel
Summary:	Development files for libopts
# Although sources are dual licensed with BSD, some autogen generated files
# are only under LGPLv3+. We drop BSD to avoid multiple licensing scenario.
License:	LGPLv3+

Requires:	automake
Requires:	%{name} = %{version}-%{release}
Requires:	%{name}-libopts = %{version}-%{release}
Requires:	pkgconfig

%description libopts-devel
This package contains development files for libopts.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

# Disable failing test
sed -i 's|errors.test||' autoopts/test/Makefile.in

%build
# Static libraries are needed to run test-suite.
export CFLAGS="$RPM_OPT_FLAGS -Wno-implicit-fallthrough -Wno-format-overflow \
		-Wno-format-truncation"
%configure

# Omit unused direct shared library dependencies.
sed --in-place --expression 's! -shared ! -Wl,--as-needed\0!g' ./libtool

make %{?_smp_mflags}

%check
make check

%install
make install INSTALL="%{__install} -p" DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -type f -name "*.la" -delete
find $RPM_BUILD_ROOT -type f -name "*.a" -delete

# Remove time stamps from generated devel man pages to avoid multilib conflicts
sed -i 's|\(It has been AutoGen-ed\).*.\(by AutoGen\)|\1 \2|' \
	$RPM_BUILD_ROOT%{_mandir}/man3/*.3

# Remove rpath.
chrpath --delete $RPM_BUILD_ROOT%{_bindir}/{columns,getdefs,%{name},xml2ag}
chrpath --delete $RPM_BUILD_ROOT%{_libdir}/lib*.so.*

rm -f $RPM_BUILD_ROOT%{_infodir}/dir

%generate_compatibility_deps

%files
%doc COPYING
%doc pkg/libopts/COPYING.gplv3
%{_bindir}/columns
%{_bindir}/getdefs
%{_bindir}/%{name}
%{_bindir}/xml2ag
%{abidir}/%{name}-option.list
%{abidir}/columns-option.list
%{abidir}/xml2ag-option.list
%{_infodir}/%{name}.info*.*
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man1/columns.1.*
%{_mandir}/man1/getdefs.1.*
%{_mandir}/man1/xml2ag.1.*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*

%files libopts
%doc pkg/libopts/COPYING.mbsd
%doc pkg/libopts/COPYING.lgplv3
%{_libdir}/libopts.so.25*

%files libopts-devel
%{_bindir}/autoopts-config
%{abidir}/autoopts-config-option.list
%{_datadir}/aclocal/autoopts.m4
%{_libdir}/libopts.so
%{abidir}/libopts.dump
%{_libdir}/pkgconfig/autoopts.pc
%{_mandir}/man1/autoopts-config.1.*
%{_mandir}/man3/*

%dir %{_includedir}/autoopts
%{_includedir}/autoopts/options.h
%{_includedir}/autoopts/usage-txt.h

%files doc
%doc AUTHORS ChangeLog NEWS README THANKS TODO

%changelog
* Fri Jan 13 2023 yuanhui <yuanhui@linux.alibaba.com> - 5.18.16-2
- add doc package

* Fri Apr 22 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 5.18.16-1
- init from upstream
- compat with guile-3.0 and fix build error
